@@ -8,6 +8,7 @@ from typing import Any, Optional, Dict, Union
 
 import aiohttp.web
 import aiohttp.abc
+import init_helpers
 from dynamic_types.class_name import prepare_class_name
 from dynamic_types.create import create_type, create_dataclass
 from init_helpers import custom_dumps, is_instance, raise_if
@@ -177,6 +178,7 @@ class JsonableAnswer(Answer):
 
     def convert_payload(self, payload):
         if payload_type := self.get_class_payload_type():
+            payload_type, _ = init_helpers.try_extract_type_notes(payload_type)
             if is_instance(payload, payload_type):
                 return payload
 
@@ -213,9 +215,13 @@ class WrappedAnswer(JsonableAnswer):
         super().__init__(payload, status, headers, charset)
 
     @classmethod
-    def _wrap_type(cls, type_: type) -> type:
-        attribute_key_to_type = {"done": bool, "result": type_} if type_ not in (None, type[None]) else {"done": bool}
-        return create_dataclass(prepare_class_name([type_],  "Wrapped"), [], attribute_key_to_type)
+    def _wrap_type(cls, type_or_annotated: type | typing.Annotated | None) -> type:
+        type_, notes = init_helpers.try_extract_type_notes(type_or_annotated)
+        attribute_key_to_type = {"done": bool}
+        if type_ not in (None, type[None]):
+            attribute_key_to_type["result"] = type_or_annotated
+        new_type_name = prepare_class_name(([type_or_annotated] if notes else []) + [type_],  "Wrapped")
+        return create_dataclass(new_type_name, [], attribute_key_to_type)
 
     def __class_getitem__(cls, modifier: Union[HttpStatusCode, ContentType, type, UnionType, type[None]]) -> type:
         if typing.get_origin(modifier) is not None or isinstance(modifier, type | UnionType):
