@@ -176,21 +176,21 @@ class HttpClient(AsyncOnStop):
         if response.status in {HttpStatusCode.OK, HttpStatusCode.Created, HttpStatusCode.Accepted}:
             return payload
         elif response.status == HttpStatusCode.BadRequest:
-            raise HTTPBadRequest(reason=payload)
+            raise HTTPBadRequest(reason=str(payload))
         elif response.status == HttpStatusCode.Unauthorized:
-            raise HTTPUnauthorized(reason=payload)
+            raise HTTPUnauthorized(reason=str(payload))
         elif response.status == HttpStatusCode.Forbidden:
-            raise HTTPForbidden(reason=payload)
+            raise HTTPForbidden(reason=str(payload))
         elif response.status == HttpStatusCode.NotFound:
-            raise HTTPNotFound(reason=payload)
+            raise HTTPNotFound(reason=str(payload))
         elif response.status == HttpStatusCode.UnprocessableEntity:
-            raise HTTPUnprocessableEntity(reason=payload)
+            raise HTTPUnprocessableEntity(reason=str(payload))
         elif response.status == HttpStatusCode.BadGateway:
-            raise HTTPBadGateway(reason=payload)
+            raise HTTPBadGateway(reason=str(payload))
         elif response.status == HttpStatusCode.ServiceUnavailable:
-            raise HTTPServiceUnavailable(reason=payload)
+            raise HTTPServiceUnavailable(reason=str(payload))
         elif response.status == HttpStatusCode.GatewayTimeout:
-            raise HTTPGatewayTimeout(reason=payload)
+            raise HTTPGatewayTimeout(reason=str(payload))
         else:
             logger.warning(f"Not processed response status code = {response.status}. body: {payload}")
-            raise HTTPInternalServerError(reason=payload)
+            raise HTTPInternalServerError(reason=str(payload))
